/*
 * Copyright 2006 Takahiro Nakamura.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package woolpack.factory;

import woolpack.el.GettingEL;
import woolpack.fn.Fn;

/**
 * {@link GettingEL}に委譲する{@link Fn}です。
 * このアダプタを使用することにより{@link Fn}のコンポジットに式言語の実装を適用することができます。
 * <br/>適用しているデザインパターン：Adapter。
 * 
 * @author nakamura
 *
 * @param <E>
 */
public class GettingELFn<E extends Exception> implements Fn<Object, Object, E> {
	private GettingEL gettingEL;
	
	public GettingELFn(final GettingEL gettingEL) {
		this.gettingEL = gettingEL;
	}

	public Object exec(final Object c) {
		return gettingEL.getValue(c);
	}

	public GettingEL getGettingEL() {
		return gettingEL;
	}
	public void setGettingEL(final GettingEL gettingEL) {
		this.gettingEL = gettingEL;
	}
}
